@@ -9,16 +9,16 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"5.1.63"
+#define MYSQL_SERVER_VERSION		"5.1.68"
 #define MYSQL_BASE_VERSION		"mysqld-5.1"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		50163
+#define MYSQL_VERSION_ID		50168
 #define MYSQL_PORT			3306
 #define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/var/run/mysql/mysql.sock"
 #define MYSQL_CONFIG_NAME		"my"
-#define MYSQL_COMPILATION_COMMENT	"OpenBSD port: mysql-server-5.1.63p0"
+#define MYSQL_COMPILATION_COMMENT	"OpenBSD port: mysql-server-5.1.68"
 
 /* mysqld compile time options */
 #endif /* _CUSTOMCONFIG_ */
